#!/bin/sh

echo ""
echo "IBM Business Process Manager Search Optimization - Data Load"
echo ""

usage() {
  echo -e -n "\n"
  echo "Loads data into pivot tables."
  echo -e -n "\n"
  echo "Usage:"
  echo -e -n "\n"
  echo "   `basename ${0}` [options...]"
  echo -e -n "\n"
  echo "Options:"
  echo "   -?, -help                             This help message"
  echo "   -profileName <name>                   Profile name"
  echo "   -deName <deName>                      The name of the deployment environment."
  echo -e -n "\n"
  exit $1
}

SCRIPT_DIR=`dirname ${0}`
ORIG_DIR=`pwd`
BIN_DIR=$SCRIPT_DIR/../../../../bin
REPLACE_WAS_HOME=$SCRIPT_DIR/../../../../
. $BIN_DIR/setupCmdLine.sh

if [ "${USER_INSTALL_ROOT:=}" = "" ]; then
  echo -e -n "\n"
  echo "Profile does not exist."
  echo -e -n "\n"
  usage 1
fi

if [ -f ${JAVA_HOME}/bin/java ]; then
  JAVA_EXE="${JAVA_HOME}/bin/java"
else
  JAVA_EXE="${JAVA_HOME}/jre/bin/java"
fi

LOGGING_PROP="-Dcom.lombardisoftware.ant.JULDefaultLogger.level=DEBUG -Djava.util.logging.config.file=$SCRIPT_DIR/loggingLoad.properties -Dtw.log4j.init=false"
LOGGING_PROP="$LOGGING_PROP -Dcom.lombardi.logging.StringFilter.excludes=contains(db.password);equals(WSVR0072W);equals(WSVR0801I);equals(WKSP0500);equals(WSVR0643I)"

ENABLE_DEBUG=false

if [ $ENABLE_DEBUG = true ]; then
   DEBUG_PROP="-Xdebug -Xrunjdwp:transport=dt_socket,address=1111,server=y,suspend=y"   
else
   DEBUG_PROP= 
fi


PLUGINS_DIR=$WAS_HOME/plugins
RUNTIMES_DIR=$WAS_HOME/runtimes
BPM_LIB_DIR=$WAS_HOME/BPM/Lombardi/lib
BPM_JDBCDRIVERS_DIR=$WAS_HOME/jdbcdrivers

CLASSPATH=$SCRIPT_DIR
CLASSPATH=$CLASSPATH:lib/search-opt.jar
CLASSPATH=$CLASSPATH:$PLUGINS_DIR/com.ibm.bpm.config.jar
CLASSPATH=$CLASSPATH:$PLUGINS_DIR/com.ibm.bpm.config.model.bspace.jar
CLASSPATH=$CLASSPATH:$PLUGINS_DIR/com.ibm.bpm.config.model.federation.jar
CLASSPATH=$CLASSPATH:$PLUGINS_DIR/com.ibm.bpm.config.model.jar
CLASSPATH=$CLASSPATH:$PLUGINS_DIR/com.ibm.bpm.config.model.rest.service.jar
CLASSPATH=$CLASSPATH:$PLUGINS_DIR/com.ibm.ffdc.jar
CLASSPATH=$CLASSPATH:$PLUGINS_DIR/com.ibm.hpel.logging.jar
CLASSPATH=$CLASSPATH:$PLUGINS_DIR/com.ibm.ws.admin.core.jar
CLASSPATH=$CLASSPATH:$PLUGINS_DIR/com.ibm.ws.admin.services.jar
CLASSPATH=$CLASSPATH:$PLUGINS_DIR/com.ibm.ws.admin.system.jar
CLASSPATH=$CLASSPATH:$PLUGINS_DIR/com.ibm.ws.bootstrap.jar
CLASSPATH=$CLASSPATH:$PLUGINS_DIR/com.ibm.ws.bpm.repository.jar
CLASSPATH=$CLASSPATH:$PLUGINS_DIR/com.ibm.ws.bpm.utils.jar
CLASSPATH=$CLASSPATH:$PLUGINS_DIR/com.ibm.ws.bpm.wccm.jar
CLASSPATH=$CLASSPATH:$PLUGINS_DIR/com.ibm.ws.emf.jar
CLASSPATH=$CLASSPATH:$PLUGINS_DIR/com.ibm.ws.javaee.dd.common.jar
CLASSPATH=$CLASSPATH:$PLUGINS_DIR/com.ibm.ws.javaee.dd.ejb.jar
CLASSPATH=$CLASSPATH:$PLUGINS_DIR/com.ibm.ws.runtime.jar
CLASSPATH=$CLASSPATH:$PLUGINS_DIR/com.ibm.ws.wccm.jar
CLASSPATH=$CLASSPATH:$PLUGINS_DIR/com.ibm.wsspi.extension.jar
CLASSPATH=$CLASSPATH:$PLUGINS_DIR/com.ibm.wsspi.proxy.extension.jar
CLASSPATH=$CLASSPATH:$PLUGINS_DIR/javax.j2ee.jacc.jar
CLASSPATH=$CLASSPATH:$PLUGINS_DIR/javax.j2ee.servlet.jar
CLASSPATH=$CLASSPATH:$PLUGINS_DIR/org.eclipse.core.runtime_.jar
CLASSPATH=$CLASSPATH:$PLUGINS_DIR/org.eclipse.emf.common.jar
CLASSPATH=$CLASSPATH:$PLUGINS_DIR/org.eclipse.emf.ecore.jar
CLASSPATH=$CLASSPATH:$PLUGINS_DIR/org.eclipse.emf.ecore.xmi.jar
CLASSPATH=$CLASSPATH:$PLUGINS_DIR/org.eclipse.equinox.common_.jar
CLASSPATH=$CLASSPATH:$PLUGINS_DIR/org.eclipse.equinox.registry.jar
CLASSPATH=$CLASSPATH:$PLUGINS_DIR/org.eclipse.osgi_.jar
CLASSPATH=$CLASSPATH:$WAS_HOME/lib/bootstrap.jar
CLASSPATH=$CLASSPATH:$BPM_LIB_DIR/jdom.jar
CLASSPATH=$CLASSPATH:$BPM_LIB_DIR/langutil.jar
CLASSPATH=$CLASSPATH:$BPM_LIB_DIR/log4j.jar
CLASSPATH=$CLASSPATH:$BPM_LIB_DIR/psapiclnt.jar
CLASSPATH=$CLASSPATH:$BPM_LIB_DIR/psclnt.jar
CLASSPATH=$CLASSPATH:$BPM_LIB_DIR/pssearch.jar
CLASSPATH=$CLASSPATH:$BPM_LIB_DIR/svrcoreclnt.jar
CLASSPATH=$CLASSPATH:$BPM_LIB_DIR/oro.jar
CLASSPATH=$CLASSPATH:$BPM_JDBCDRIVERS_DIR/DB2/db2jcc_license_cisuz.jar 

$JAVA_EXE $DEBUG_PROP $LOGGING_PROP -Dwas.install.root=${WAS_HOME} -Dcom.ibm.ws.management.standalone=true -Dwas.repository.root=$USER_INSTALL_ROOT/config -Duser.install.root=$USER_INSTALL_ROOT -classpath $CLASSPATH com.lombardisoftware.tools.optimization.search.DataLoad $*
