#!/bin/bash

# All Rights Reserved * Licensed Materials - Property of IBM
# US Government Users Restricted Rights - Use, duplication or disclosure
# restricted by GSA ADP Schedule Contract with IBM Corp.

#set -o xtrace 

CUR_DIR=`pwd`
binDir=`dirname "$0"`
if [ -r "${binDir}/setupCmdLine.sh" ]; then
. "${binDir}/setupCmdLine.sh"
fi




if [ -f ${JAVA_HOME}/bin/java ]; then
    JAVA_EXE="${JAVA_HOME}/bin/java"
else
    JAVA_EXE="${JAVA_HOME}/jre/bin/java"
fi

function usage() {
echo "" 
echo "Command invocation example"
echo ""
echo "./bpmdc.sh -type=Dump -PMR=(pmrNumber) -config=yes -uploadToIBM=yes -outputDirectory=(location of output directory) -user=(wsadmin username) -password=(wsadmin password) -count=(number of dumps) -interval=(number of seconds) -server=(name of server) -dumptype=Thread -soapport=8879"
echo " where type=General / Install / Dump {Optional}  {Defaults to General}  Note: Dump option is not supported on Solaris" 
echo "  PMR in 11111.bbb.CCC format	{Optional}  {Defaults to none, No upload}"
echo "  config option to collect the config directory {Optional}  {Defaults to No}"
echo "  uploadToIBM to send the collected data with FTP option {Optional} {Defaults to No}"
echo "  outputDirectory is the location where you want to create the output zip { Defaults to WAS_HOME/BPM/isadc folder } You should enclose the outputDirectory in double quotes if it has a blank character"
echo "  user & password : the user name and password for running wsadmin.sh/bat"
echo "  count & interval {Optional} {Defaults to 1 for count, and 0 for interval} {if type=Dump specified, bpmdc should do this <count> times with a delay of <interval> in between}"
echo "  server is the name of the server which you want to collect dumps for. If specified, you must run bpmdc in the <Profile_Home>/bin of the profile where the server was created. {Madatory if type=Dump specified}"
echo "  dumptype=Thread / Heap / System   {Optional}    {The Thread dump type should trigger a javacore or thread dump depending on OS, The Heap dump type should trigger a heapdump using the appropriate command depending on the OS. The System dump would only work on AIX,Linux or Windows. It should run jextract on the core file created.}"
echo "  soapport is the port number of the SOAP connection of the wsadmin, if specifies -server, use the SOAP_CONNECTOR_ADDRESS of that server."
echo "  -help to display help"
echo "" 		
echo "If invoked without any option then the default options will be picked."
echo "The Default options are"
echo "-type=General -config=no -uploadToIBM=No {PMR not needed} -outputDirectory=(Full path to collection)"

}

# #${USER_INSTALL_ROOT}/bin/isadc should be set to the place where ISA DC core is 

ISADC_HOME="$WAS_HOME/BPM/isadc"
OUTPUTDIRECTORY=$ISADC_HOME
if [ "$1" == "" ]; then

	COLLECTORTYPE=""
	UPLOAD="false" 
	CONFIG="false"
	PMRNUMBER=""
	
#	echo "start running isadc"  
fi

while [ "$1" != "" ]; do
	PARAM=`echo $1 | awk -F= '{print $1}'`
    VALUE=`echo $1 | awk -F= '{print $2}'`
    case $PARAM in
        -[hH]  | -[hH][eE][lL][pP] )
            usage
            exit
            ;;
        -[tT][yY][pP][eE] | -[cC][oO][lL][lL][eE][cC][tT][oO][rR][tT][yY][pP][eE] )
            COLLECTORTYPE=$VALUE
            ;;
        -[cC][oO][nN][fF][iI][gG])
            CONFIG=$VALUE
            ;;
        -[uU][pP][lL][oO][aA][dD][tT][oO][iI][bB][mM])
            UPLOAD=$VALUE
            ;;
        -[pP][mM][rR])
            PMRNUMBER=$VALUE
            ;;
        -[oO][uU][tT][pP][uU][tT][dD][iI][rR][eE][cC][tT][oO][rR][yY] )
        	OUTPUTDIRECTORY=$VALUE
        	;;
		-[uU][sS][eE][rR])
			USER=$VALUE
			;;
		-[pP][aA][sS][sS][wW][oO][rR][dD])
			PASSWORD=$VALUE
			;;
		-[cC][oO][uU][nN][tT])
			COUNT=$VALUE
			;;
		-[iI][nN][tT][eE][rR][vV][aA][lL])
			INTERVAL=$VALUE
			;;
		-[sS][eE][rR][vV][eE][rR])
			SERVER=$VALUE
			;;
		-[dD][uU][mM][pP][tT][yY][pP][eE])
			DUMPTYPE=$VALUE
			;;
		-[sS][oO][aA][pP][pP][oO][rR][tT])
			SOAPPORT=$VALUE
			;;
        *)
            echo "ERROR: unknown parameter \"$PARAM\""
            usage
            exit 1
            ;;
    esac
shift
done

if [ "$COLLECTORTYPE" == "" ]; then
COLLECTORTYPE="General" 
fi

if [ "$COLLECTORTYPE" != "General" ]  && [ "$COLLECTORTYPE" != "general" ] && [ "$COLLECTORTYPE" != "Install" ] && [ "$COLLECTORTYPE" != "install" ] && [ "$COLLECTORTYPE" != "Dump" ] && [ "$COLLECTORTYPE" != "dump" ]; then
echo "ERROR: only General, Install, and Dump can be the value for the parameter -type or -collectorType"
usage
exit 1
fi

#echo $USER
#echo $PASSWORD
#echo $SERVER
#echo $USER_INSTALL_ROOT
#echo $SOAPPORT

#validate the parameters for Dump option
if [ "$COLLECTORTYPE" == "Dump" ] || [ "$COLLECTORTYPE" == "dump" ]; then
	if [ "$USER" == "" ]; then
	echo "ERROR: -user must be specified when the collectorType is Dump"
	usage
	exit 1
	fi
	if [ "$PASSWORD" == "" ]; then
	echo "ERROR: -password must be specified when the collectorType is Dump"
	usage
	exit 1
	fi
	if [ "$SERVER" == "" ]; then
	echo "ERROR: -server must be specified when the collectorType is Dump"
	usage
	exit 1
	fi
	if [ ! -d $USER_INSTALL_ROOT/logs/$SERVER ]; then
	echo "ERROR: this script must be run in the <Profile_Home>/bin of the profile on which the server you specified was created"
	usage
	exit 1
	fi
	if [ "$SOAPPORT" == "" ]; then
	echo "ERROR: -soapport must be specified when the collectorType is Dump"
	usage
	exit 1
	fi
	if [ "$DUMPTYPE" == "" ]; then
	DUMPTYPE="Thread"
	fi
	if [ "$COUNT" == "" ]; then
	COUNT="1"
	fi
	if [ "$INTERVAL" == "" ]; then
	INTERVAL="0"
	fi
	
	WSADMIN="$WAS_HOME/bin/wsadmin.sh -user $USER -password $PASSWORD -conntype SOAP -port $SOAPPORT"

else
#	if [ "$USER" != "" ]; then
#		echo "ERROR: -user should not be specified when the collectorType is not Dump"
#		usage
#		exit 1
#	fi
	if [ "$PASSWORD" != "" ]; then
		echo "ERROR: -password should not be specified when the collectorType is not Dump"
		usage
		exit 1
	fi
	if [ "$SERVER" != "" ]; then
		echo "ERROR: -server should not be specified when the collectorType is not Dump"
		usage
		exit 1
	fi	
	if [ "$SOAPPORT" != "" ]; then
		echo "ERROR: -soapport should not be specified when the collectorType is not Dump"
		usage
		exit 1
	fi
	if [ "$DUMPTYPE" != "" ]; then
		echo "ERROR: -dumptype should not be specified when the collectorType is not Dump"
		usage
		exit 1
	fi
	if [ "$COUNT" != "" ]; then
		echo "ERROR: -count should not be specified when the collectorType is not Dump"
		usage
		exit 1
	fi
	if [ "$INTERVAL" != "" ]; then
		echo "ERROR: -interval should not be specified when the collectorType is not Dump"
		usage
		exit 1
	fi

fi

function isint(){
  if [ $# -lt 1 ]; then
    return 0
  fi
  if [[ $1 =~ ^-?[1-9][0-9]*$ ]]; then
    return 1
  fi
  if [[ $1 =~ ^0$ ]]; then
    return 1
  fi
  return 0
}
function ispositiveint(){
  isint $1
  if [ $? -eq 0 ]; then
    return 0
  fi
  if [ $1 -lt 1 ]; then
    return 0
  fi
  return 1
}
function isnonnegativeint(){
  isint $1
  if [ $? -eq 0 ]; then
    return 0
  fi
  if [ $1 -lt 0 ]; then
    return 0
  fi
  return 1
}

#validate parameter count and interval
#echo $COUNT
if [ "$COLLECTORTYPE" == "Dump" ] || [ "$COLLECTORTYPE" == "dump" ]; then
  ispositiveint $COUNT
  if [ $? -eq 0 ]; then
    echo "parameter count must be a positive integer"
    usage
    exit 1
  fi
  isnonnegativeint $INTERVAL
  if [ $? -eq 0 ]; then
    echo "parameter interval must be a nonnegative integer"
    usage
    exit 1
  fi
fi

DUMP_OPTION=""
if [ "$DUMPTYPE" != "" ]; then
        if [ "$DUMPTYPE" == "Thread" ]; then
        DUMP_OPTION="dumpThreads"
        fi
        if [ "$DUMPTYPE" == "Heap" ]; then
        DUMP_OPTION="generateHeapDump"
        fi
        if [ "$DUMPTYPE" == "System" ]; then
        DUMP_OPTION="generateSystemDump"
        JEXTRACT="${JAVA_HOME}/jre/bin/jextract"
        Temp_FILE="$ISADC_HOME/util/Temp.txt"
        fi
fi
if [ "$DUMPTYPE" != "" ] && [ "$DUMP_OPTION" == "" ]; then
        echo "dumptype must be one of Thread, Heap, and System."
        usage
        exit 1
fi

if [ "$CONFIG" != "" ] && [ "$CONFIG" != "false" ]; then
	if [ "$CONFIG" != "YES" ] && [ "$CONFIG" != "Yes" ] && [ "$CONFIG" != "yes" ] && [ "$CONFIG" != "Y" ] && [ "$CONFIG" != "y" ] && [ "$CONFIG" != "NO" ] && [ "$CONFIG" != "No" ] && [ "$CONFIG" != "no" ] && [ "$CONFIG" != "N" ] && [ "$CONFIG" != "n" ]; then
		echo "config must be yes or no."
		usage
		exit 1
	fi
fi

if [ "$UPLOAD" != "" ] && [ "$UPLOAD" != "false" ]; then
        if [ "$UPLOAD" != "YES" ] && [ "$UPLOAD" != "Yes" ] && [ "$UPLOAD" != "yes" ] && [ "$UPLOAD" != "Y" ] && [ "$UPLOAD" != "y" ] && [ "$UPLOAD" != "NO" ] && [ "$UPLOAD" != "No" ] && [ "$UPLOAD" != "no" ] && [ "$UPLOAD" != "N" ] && [ "$UPLOAD" != "n" ]; then
                echo "uploadToIBM must be yes or no."
                usage
                exit 1
        fi
fi

echo "Running the Collector command with the following options"
echo "/-------------------------------------------------------------------------------"
echo "type = $COLLECTORTYPE"
if [ "$COLLECTORTYPE" == "Dump" ] || [ "$COLLECTORTYPE" == "dump" ]; then
	echo "dumptype = $DUMPTYPE"
	echo "count = $COUNT"
	echo "interval = $INTERVAL"
fi
echo "config = $CONFIG"
echo "uploadToIBM = $UPLOAD"
echo "PMR = $PMRNUMBER"
echo "outputDirectory = $OUTPUTDIRECTORY"
echo "\-------------------------------------------------------------------------------"
echo ""
echo "The collection is beginning and could take a few minutes depending on the size."


if [ "$DUMPTYPE" == "System" ]; then
	echo "### Begin generating system dump" > $Temp_FILE
fi	

if [ "$COLLECTORTYPE" == "Dump" ] || [ "$COLLECTORTYPE" == "dump" ]; then
	echo "Connecting to server $SERVER at soap port $SOAPPORT to run the server dumps..."
	for ((i=0; i<$COUNT; i++))
	do
	   $WSADMIN -F $ISADC_HOME/util/dump.jacl $SERVER $DUMP_OPTION
	   wsadminRet=$?
           if [ "$wsadminRet" != "0" ]; then
               echo Wsadmin throws out a error, please examine the exception message above and check your inputs.
           #    echo "Error Num: $wsadminRet"
           #    usage
               exit 1
           fi
           echo "sleep $INTERVAL seconds"
	   sleep $INTERVAL
	done

fi

if [ "$DUMPTYPE" == "System" ]; then
	echo "Running jextract tool ( it could take a couple of minutes ) ..."
	$JAVA_EXE -cp $ISADC_HOME/util/dcutil.jar  com.ibm.ws.bpm.isadc.main.SystemDumpCollectorMain $JEXTRACT $USER_INSTALL_ROOT $Temp_FILE
	rm -f $Temp_FILE
fi

if [ "$UPLOAD" == "" ]; then
UPLOAD="false"
fi

if [ "$CONFIG" == "" ]; then
CONFIG="false"
fi

if [ "$PMRNUMBER" == "" ]; then
UPLOAD="false"
else  
isValidPMR=false
isValidLength=false

#validate PMR format 
#lengthofPMR=echo 'expr length "$PMRNUMBER"'
lengthofPMR=$(expr length $PMRNUMBER)
# check if length is 15

if [ "$lengthofPMR" == "15" ]; then
	isValidLength=true
fi

firstDot=$(expr index "$PMRNUMBER" ,.)
	if [ "$firstDot" == "6" ]; then 
		remainStr=${PMRNUMBER:6}
		secondDot=$(expr index "$remainStr" ,.)
		if [ "$secondDot" == "4" ]; then
			remainStr1=${remainStr:4}
			thirdDot=$(expr index "$remainStr1" ,.)
			if [ "$thirdDot" == "0" ]; then 
				isValidPMR=true
			fi
		fi
	fi

if [ "$isValidPMR" != "true" ]  || [ "$isValidLength" != "true" ]; then
echo ""
echo "Wrong PMR format - $PMRNUMBER" 
echo "PMR Format should be PPPPP.BBB.CCC"
echo "where PPPPP is PMR Number, BBB is the branch and CCC is the country code."
usage
exit 1
fi

fi


if [ "$OUTPUTDIRECTORY" != "$ISADC_HOME" ]; then
	if [ ! -d "$OUTPUTDIRECTORY" ]
   		then
      		mkdir -p $OUTPUTDIRECTORY
	fi

fi

DATE_TIME=$(date +"%Y%m%d_%H%M%S")

if [ "$PMRNUMBER" != "" ]; then
	if [ "$UPLOAD" == "false" ]; then
		COLLECT_FILENAME="$OUTPUTDIRECTORY"/"$PMRNUMBER"."$WAS_NODE"_"$COLLECTORTYPE"_"$DATE_TIME".zip
	else 
		COLLECT_FILENAME="$OUTPUTDIRECTORY"/"$WAS_NODE"_"$COLLECTORTYPE"_"$DATE_TIME".zip
		FILENAME_ECUREP="$OUTPUTDIRECTORY"/"$PMRNUMBER"."$WAS_NODE"_"$COLLECTORTYPE"_"$DATE_TIME".zip
	fi
else 
	COLLECT_FILENAME="$OUTPUTDIRECTORY"/"$WAS_NODE"_"$COLLECTORTYPE"_"$DATE_TIME".zip
fi

if [ "$COLLECTORTYPE" == "Dump" ] || [ "$COLLECTORTYPE" == "dump" ]; then
	if [ "$SERVER" != "" ]; then
		if [ "$PMRNUMBER" != "" ]; then
        		if [ "$UPLOAD" == "false" ]; then
                		COLLECT_FILENAME="$OUTPUTDIRECTORY"/"$PMRNUMBER"."$WAS_NODE"_"$COLLECTORTYPE"_"$SERVER"_"$DATE_TIME".zip
        		else
                		COLLECT_FILENAME="$OUTPUTDIRECTORY"/"$WAS_NODE"_"$COLLECTORTYPE"_"$SERVER"_"$DATE_TIME".zip
                		FILENAME_ECUREP="$OUTPUTDIRECTORY"/"$PMRNUMBER"."$WAS_NODE"_"$COLLECTORTYPE"_"$SERVER"_"$DATE_TIME".zip
        		fi
		else
        		COLLECT_FILENAME="$OUTPUTDIRECTORY"/"$WAS_NODE"_"$COLLECTORTYPE"_"$SERVER"_"$DATE_TIME".zip
		fi
	
	fi
fi

#RESP_FILE="ISADC_HOME/util/ResponseFile.txt"
#PROP_FILE="ISADC_HOME/util/properties.txt" 
RESP_FILE="$ISADC_HOME/util/ResponseFile.txt"
PROP_FILE="$ISADC_HOME/util/properties.txt" 
echo "### Begin Response File" > $RESP_FILE
echo "### Begin Properties File" > $PROP_FILE

echo "10.CollectionZipName=$COLLECT_FILENAME" >> $RESP_FILE
echo "20.YesNo=1" >> $RESP_FILE
if [ "$COLLECTORTYPE" == "General" ]  || [ "$COLLECTORTYPE" == "general" ]; then  
echo "30.CollectionOption=1" >> $RESP_FILE
fi 
if [ "$COLLECTORTYPE" == "Install" ] || [ "$COLLECTORTYPE" == "install" ]; then 
echo "30.CollectionOption=2" >> $RESP_FILE
fi
if [ "$COLLECTORTYPE" == "Dump" ]  || [ "$COLLECTORTYPE" == "dump" ]; then  
echo "30.CollectionOption=3" >> $RESP_FILE
fi
 
if [ "$CONFIG" == "yes" ] || [ "$CONFIG" == "Yes" ] || [ "$CONFIG" == "YES" ] || [ "$CONFIG" == "y" ] || [ "$CONFIG" == "Y" ]; then 
echo "config=true">> $PROP_FILE
else 
echo "config=$CONFIG">> $PROP_FILE
fi


if [ "$UPLOAD" == "yes" ] || [ "$UPLOAD" == "Yes" ] || [ "$UPLOAD" == "YES" ] || [ "$UPLOAD" == "y" ] || [ "$UPLOAD" == "Y" ]; then
echo "upload=$UPLOAD">> $PROP_FILE
echo "pmr.number=$PMRNUMBER">> $PROP_FILE

echo "40.SelectListOption=2">> $RESP_FILE
echo "50.OptionToCompleteInputDialog=1" >> $RESP_FILE
echo "60.MultipleChoiceInputRequest=1" >> $RESP_FILE

else 
echo "40.SelectListOption=4" >> $RESP_FILE
echo "50.OptionToCompleteInputDialog=1" >> $RESP_FILE
fi


#invoke Command

#

#Set license
LAPSTATUS_HOME=$ISADC_HOME/lap_status
LICENSE_HOME=$ISADC_HOME/licenses
CONSOLE_MODE=-text_only
if [ ! -d $LAPSTATUS_HOME ];
then
mkdir $LAPSTATUS_HOME 
fi
if [ ! -d $LAPSTATUS_HOME/license ];
then
mkdir $LAPSTATUS_HOME/license
fi
#if test -f $ISADC_HOME/lap_status/license/status.dat 
#then
#cp $ISADC_HOME/lap_status/license/status.dat $LAPSTATUS_HOME/license/status.dat
#fi

if [ ! -f $ISADC_HOME/lap_status/license/status.dat ];
then
echo "Running License Acceptance Process Tool"
$JAVA_EXE -cp $LICENSE_HOME/LAPApp.jar  com.ibm.lex.lapapp.LAP -l $LICENSE_HOME -s $LAPSTATUS_HOME  $CONSOLE_MODE
fi

#Check to see if license was accepted 
if [ -f $LAPSTATUS_HOME/license/status.dat ];
then


"$ISADC_HOME/isadc.sh" -silent "$ISADC_HOME/util/ResponseFile.txt" > "$ISADC_HOME/util/ResponseLog.txt"  2>&1
if [ "$COLLECTORTYPE" == "Dump" ] || [ "$COLLECTORTYPE" == "dump" ]; then
#Clean up the dump files
echo "USER_INSTALL_ROOT = $USER_INSTALL_ROOT"
	if [ "$DUMPTYPE" == "Thread" ]; then
		FILENUMBER=$(ls $USER_INSTALL_ROOT | grep 'javacore.*'|wc -l)
		if [ $FILENUMBER -gt 0 ];
		then
			rm -f $USER_INSTALL_ROOT/javacore.*
		fi
	fi
	if [ "$DUMPTYPE" == "Heap" ]; then
		FILENUMBER=$(ls $USER_INSTALL_ROOT | grep 'heapdump.*'|wc -l)
		if [ $FILENUMBER -gt 0 ];
		then
			rm -f $USER_INSTALL_ROOT/heapdump.*
		fi
	fi
	if [ "$DUMPTYPE" == "System" ]; then
		FILENUMBER=$(ls $USER_INSTALL_ROOT | grep 'core.*'|wc -l)
		if [ $FILENUMBER -gt 0 ];
		then
			rm -f $USER_INSTALL_ROOT/core.*
		fi
	fi
fi

else 
echo "You must accept the license before running ISA Data Collector"
fi
if [ -r "$COLLECT_FILENAME" ] && [ "$COLLECT_FILENAME" != "" ]; then
echo ""
echo "/-------------------------------------------------------------------------------"
echo "^| Your collection file is located at :"
echo "^| $COLLECT_FILENAME"
echo "\-------------------------------------------------------------------------------"
echo ""
echo "Collection is complete"
exit 0
else 
	if  [ -r $FILENAME_ECUREP ] && [ "$FILENAME_ECUREP" != "" ]; then
		echo ""
		echo "/-------------------------------------------------------------------------------"
		echo "^| Your collection file is located at :"
		echo "^| $FILENAME_ECUREP"
		echo "\-------------------------------------------------------------------------------"
		echo ""
		echo "Collection is complete"
		exit 0
	else 
		echo "Collection failed.  The file $COLLECT_FILENAME has not been created."
                echo "This problem may be caused by insufficient permission.  Please see logs." 
		exit 1
	fi
fi
